bayespy.utils.misc.CholeskySparse.trace_solve_gradient
======================================================

.. currentmodule:: bayespy.utils.misc

.. automethod:: CholeskySparse.trace_solve_gradient